@@ -5,7 +5,9 @@ class Eigenvector(Vector):
 
     eigenvalue: float
 
-    def __init__(self, eigenvalue: float, values: list):
+    def __init__(self,
+                 eigenvalue: float,
+                 values: list):
         """
         A constructor of Eigenvector which takes a double eigenValue and an list values as inputs.
         It calls its super class Vector with values list and initializes eigenValue variable with its
